package org.colinvella.fancyfish.gui;

import java.awt.Color;
import java.util.Random;

import org.colinvella.fancyfish.FancyFishMod;
import org.colinvella.fancyfish.inventory.TeleportContainer;
import org.colinvella.fancyfish.item.FishScaleItem;
import org.colinvella.fancyfish.item.FishScaleItem.Colour;
import org.colinvella.fancyfish.tileentity.TeleportTileEntity;
import org.lwjgl.opengl.GL11;

import net.minecraft.client.renderer.GlStateManager;
import net.minecraft.inventory.IInventory;
import net.minecraft.item.ItemStack;
import net.minecraft.util.ResourceLocation;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

@SideOnly(Side.CLIENT)
public class TeleportGuiContainer extends ModGuiContainer
{
	public TeleportGuiContainer(IInventory playerInventory, TeleportTileEntity teleportTileEntity)
	{
		super(new TeleportContainer(playerInventory, teleportTileEntity));
		this.playerInventory = playerInventory;
		this.teleportTileEntity = teleportTileEntity;
		this.inventoryRows = 1;
		this.xSize = 176;
		this.ySize = 172;
	}

	@Override
    protected void drawGuiContainerForegroundLayer(int mouseX, int mouseY)
    {
        this.fontRendererObj.drawString(this.teleportTileEntity.getDisplayName().getUnformattedText(), 8, 6, 0x404040);
        this.fontRendererObj.drawString(this.playerInventory.getDisplayName().getUnformattedText(), 8, this.ySize - 96 + 3, 0x404040);
    }
    
	@Override public void initGui()
	{
		super.initGui();
		guiLeft = (this.width - this.xSize) / 2;
		guiTop = (this.height - this.ySize) / 2;
		teleportLeft = this.width / 2 - 32;
		teleportTop = this.guiTop + 46 - 32;
	};
	
	@Override
	protected void drawGuiContainerBackgroundLayer(float partialTicks, int mouseX, int mouseY)
	{
        GlStateManager.pushAttrib();

        this.mc.getTextureManager().bindTexture(TELEPORT_GUI_BACKGROUND);
        this.drawTexturedModalRect(guiLeft, guiTop, 0, 0, this.xSize, this.ySize);

		ItemStack itemStack = this.inventorySlots.getSlot(0).getStack();

		GlStateManager.enableBlend();
		GlStateManager.enableAlpha();
		//GlStateManager.blendFunc(GL11.GL_SRC_ALPHA, GL11.GL_ONE);

		Colour colour = null;
		
		if (itemStack != null)
		{
			FishScaleItem fishScaleItem = (FishScaleItem) itemStack.getItem();
			colour = fishScaleItem.getColour();
			
			// particles under teleport cover
			GlStateManager.blendFunc(GL11.GL_SRC_ALPHA, GL11.GL_ONE);
			GlStateManager.color(colour.red, colour.green, colour.blue, this.teleportTileEntity.getCharge());
			for (int particle = 0; particle < 32; particle++)
			{
				this.drawTexturedModalRect(teleportLeft + random.nextInt(56), teleportTop + random.nextInt(56), 176, 128, 16, 16);
			}
		}
		
		// teleport cover
		GlStateManager.blendFunc(GL11.GL_SRC_ALPHA, GL11.GL_ONE_MINUS_SRC_ALPHA);
		GlStateManager.color(1, 1, 1, 1);
		this.drawTexturedModalRect(teleportLeft , teleportTop, 176, 0, 64, 64);

		// panel glow
		if (itemStack != null)
		{
			GlStateManager.color(colour.red, colour.green, colour.blue, this.teleportTileEntity.getCharge());
			this.drawTexturedModalRect(teleportLeft , teleportTop, 176, 64, 64, 64);
		}
        
        GlStateManager.popAttrib();
	}
	
	@Override
	public void updateScreen()
	{
        super.updateScreen();
	};
	
	private IInventory playerInventory;
	private TeleportTileEntity teleportTileEntity;
	private int inventoryRows;
	private int guiLeft = 0;
	private int guiTop = 0;
	private int teleportLeft = 0;
	private int teleportTop = 0;
	private Random random = new Random();
	
    private static final ResourceLocation TELEPORT_GUI_BACKGROUND
    	= new ResourceLocation(FancyFishMod.MOD_ID + ":textures/gui/Teleport.png");
}
